#include <webkit/webkit.h>

static void webLoadFinished(WebKitWebPage* page, WebKitWebFrame* frame, gpointer data)
{
    g_timeout_add(1000, (GSourceFunc)clutter_main_quit, NULL);
}

int main(int argc, char** argv)
{
    if (argc != 2) {
        g_print("Usage: %s <normal|malicious>\n", argv[0]);
        return 1;
    }

    if (clutter_init(&argc, &argv) != CLUTTER_INIT_SUCCESS)
        return 1;

    webkit_init();

    MxWindow* window = mx_window_new();

    ClutterActor* webView = mx_web_view_new();
    clutter_actor_set_size(webView, 800, 600);
    mx_window_set_child(window, webView);

    mx_window_show(window);

    WebKitWebPage* page = webkit_iweb_view_get_page(WEBKIT_IWEB_VIEW(webView));
    g_signal_connect(page, "web-load-finished",
                     G_CALLBACK(webLoadFinished), webView);

    /* Normal case, we just load a page! */
    if (g_str_equal(argv[1], "normal")) {
        webkit_iweb_view_load_uri(WEBKIT_IWEB_VIEW(webView), "http://gnome.org/");
        clutter_main();
        return 0;
    }

    /* Malicious case, we'll try to load the contents of the user's bash history. */
    char* filename = g_strdup_printf("%s/.bash_history", g_get_home_dir());

    char* contents;
    GError* error = NULL;
    g_file_get_contents(filename, &contents, NULL, &error);

    if (error) {
        contents = g_strdup(error->message);
        g_clear_error(&error);
    }

    webkit_web_page_load_string(page, contents, "text/plain", "UTF-8", "file://");

    clutter_main();

    return 0;
}
