#! /bin/bash

# This test script is very simple. 
# 1) Start Xoo with some predefined server dpy number.
# 2) Launch 'keyevent-waiter', a very simple program waiting for a hardcoded series of keyboard inputs, running in the nested Xephyr server.
# 3) Forge a series of mouse clicks at different locations on device UI skin. (on device buttons or not)
# 4) On 'keyevent-waiter' termination, output test's success/failure msg based on exit value written to a file
#    note: the keyevent-waiter exit code must be stored in a file because the process is running in another bash env.
#          and we can't therefore retrieve the code with $?
# 5) clean up

# This function kills programs that may have beed
# left running by the test
function clean_up {

# Kill xoo and Xnest
# We're using disown here to keep jobs monitor from
# ouputting the annoying "Terminated".
disown $xoo_pid &> /dev/null
kill $xoo_pid &> /dev/null

kill $xnest_pid &> /dev/null
}

# This function writes out test results and exits
function end_test {

if [ $out -eq 0 ]; then
   echo "EMULATED_SOFT_KEYS_TEST: PASSED"
else
   echo "EMULATED_SOFT_KEYS_TEST: FAILED"
fi

clean_up

exit 0
}

# Some constant declarations
test_name=EMULATES_SOFT_KEYS_TEST
ret_file="$HOME/ret"i
script_dir="$( cd -P "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
x_arr=(113 301 401 566 630)
y_arr=(461 469 469 459 459)
out=1

rm -f $ret_file

xoo --device generic --xnest-dpy :1 -t $test_name &> /dev/null &
sleep 2.5
xoo_pid=`ps -elf | grep "xoo --device" | grep -v grep | awk '{print $4}'`
xnest_pid=`ps -elf | grep "Xnest :1" | grep -v grep | awk '{print $4}'`
if [ "$xoo_pid" == "" ]; then
  end_test 
fi

DISPLAY=:1 xterm -geometry 98x26 -e "$script_dir/keyevent_waiter $ret_file" &
sleep 1
waiter_pid=`ps -elf | grep keyevent_waiter | grep -v grep | grep -v xterm | awk '{print $4}'`
sleep 0.5

# Let's emulate the X events
for i in {0..4}
do
  xdotool search --name $test_name mousemove --window %1 ${x_arr[i]} ${y_arr[i]}
  sleep 0.1
  xdotool click 1
done

# Let's wait for our keyevent_waiter to terminate
while [ -e /proc/$waiter_pid ]; do sleep 0.1; done

# check the test's result
if [ -f $ret_file ]; then
  out=`cat $ret_file`
else
  out=1
fi

end_test
